==> haskell-http-client-tls-0.3.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.3.1
id: http-client-tls-0.3.3.1-LqFK0CJFLyXLwm84Ag5hbB
key: http-client-tls-0.3.3.1-LqFK0CJFLyXLwm84Ag5hbB
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
abi: 613dabb4460c55d94e0fe9dc6a9c8b28
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-tls-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-tls-0.3.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/http-client-tls-0.3.3.1
hs-libraries: HShttp-client-tls-0.3.3.1-LqFK0CJFLyXLwm84Ag5hbB
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
    connection-0.2.6-7kvwKDE1BL7BnzWRFdelxA
    cryptonite-0.21-H8Zyk55iekJ2xfDZlsLCTV
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.5-IwHpSkqRbxJJXgW2dGYNud
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    memory-0.14-1UtwNv7NYkX9dHSkMG3pxY
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    tls-1.3.9-7VPRBtCSFjp9VWbOGeabxj transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.3.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.3.1
id: http-client-tls-0.3.3.1-7WmxQtwFXc1D6MHeSGtCxL
key: http-client-tls-0.3.3.1-7WmxQtwFXc1D6MHeSGtCxL
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
abi: ee64aca0be18ac0533f0c5de9c2e9cd3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-tls-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-client-tls-0.3.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/http-client-tls-0.3.3.1
hs-libraries: HShttp-client-tls-0.3.3.1-7WmxQtwFXc1D6MHeSGtCxL
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    connection-0.2.7-D2n3VIQaNMUDv11NnHmpKO
    cryptonite-0.21-HmFMsJMITqYC3JT3NLI1v7
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6-Auo5TBlvhCDIsl575hjQy2
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    memory-0.14.1-2zYO5UcujuQ8oEi6uZqbHo
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    tls-1.3.9-9hJarkwYzYhCvX1UB21o6G transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
